@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2015, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -70,7 +70,7 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         return this.thisAsProxy;
     }
 
-    protected MySQLConnection getActiveMySQLConnection() {
+    public MySQLConnection getActiveMySQLConnection() {
         synchronized (this.thisAsProxy) {
             return this.thisAsProxy.currentConnection;
         }
@@ -88,6 +88,7 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         getActiveMySQLConnection().checkClosed();
     }
 
+    @Deprecated
     public void clearHasTriedMaster() {
         getActiveMySQLConnection().clearHasTriedMaster();
     }
@@ -1724,6 +1725,10 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         return getActiveMySQLConnection().getHost();
     }
 
+    public String getHostPortPair() {
+        return getActiveMySQLConnection().getHostPortPair();
+    }
+
     public long getId() {
         return getActiveMySQLConnection().getId();
     }
@@ -1856,6 +1861,7 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         return getActiveMySQLConnection().hasSameProperties(c);
     }
 
+    @Deprecated
     public boolean hasTriedMaster() {
         return getActiveMySQLConnection().hasTriedMaster();
     }
@@ -2080,6 +2086,7 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         getActiveMySQLConnection().setInGlobalTx(flag);
     }
 
+    @Deprecated
     public void setPreferSlaveDuringFailover(boolean flag) {
         getActiveMySQLConnection().setPreferSlaveDuringFailover(flag);
     }
@@ -2216,6 +2223,14 @@ public class MultiHostMySQLConnection implements MySQLConnection {
         getActiveMySQLConnection().setLoadBalanceSQLStateFailover(loadBalanceSQLStateFailover);
     }
 
+    public void setLoadBalanceHostRemovalGracePeriod(int loadBalanceHostRemovalGracePeriod) throws SQLException {
+        getActiveMySQLConnection().setLoadBalanceHostRemovalGracePeriod(loadBalanceHostRemovalGracePeriod);
+    }
+
+    public int getLoadBalanceHostRemovalGracePeriod() {
+        return getActiveMySQLConnection().getLoadBalanceHostRemovalGracePeriod();
+    }
+
     public boolean isProxySet() {
         return this.getActiveMySQLConnection().isProxySet();
     }
