@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014, 2015, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -24,14 +24,14 @@
 package testsuite.fabric.jdbc;
 
 import java.sql.ResultSet;
-import java.sql.Statement;
 import java.sql.SQLException;
-
-import testsuite.fabric.BaseFabricTestCase;
+import java.sql.Statement;
 
 import com.mysql.fabric.jdbc.FabricMySQLConnection;
 import com.mysql.fabric.jdbc.FabricMySQLDataSource;
 
+import testsuite.fabric.BaseFabricTestCase;
+
 /**
  * TODO: document required setup for this test
  */
@@ -118,9 +118,10 @@ public class TestHABasics extends BaseFabricTestCase {
         Thread.sleep(secs);
         System.err.println("Continuing");
         try {
-            s.executeQuery("show variables like 'port'");
+            rs = s.executeQuery("show variables like 'port'");
+            rs.close();
             fail("Master should be unavailable");
-        } catch(SQLException ex) {
+        } catch (SQLException ex) {
             rs = s.executeQuery("show variables like 'port'");
             rs.next();
             System.err.println("New master Port: " + rs.getString(2));
@@ -134,16 +135,16 @@ public class TestHABasics extends BaseFabricTestCase {
      * therefore always has the latest state. Future shared state implementation may loosen this constraint.
      */
     public void manualTestNewConnHasNewState() throws Exception {
-        FabricMySQLConnection conn = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
-        conn.setServerGroupName("ha_config1_group");
+        FabricMySQLConnection conn1 = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
+        conn1.setServerGroupName("ha_config1_group");
 
         String query = "SELECT CONCAT(@@hostname, ':', @@port) AS 'Value'";
-        ResultSet rs = conn.createStatement().executeQuery(query);
+        ResultSet rs = conn1.createStatement().executeQuery(query);
         rs.next();
         String startingMaster = rs.getString(1);
         System.err.println("Starting master: " + startingMaster);
         rs.close();
-        conn.close();
+        conn1.close();
 
         // allow time to perform manual failover
         int secs = 15000;
@@ -152,15 +153,15 @@ public class TestHABasics extends BaseFabricTestCase {
         System.err.println("Continuing");
 
         // do the exact same thing and expect it to connect to the new master without an exception
-        conn = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
-        conn.setServerGroupName("ha_config1_group");
+        conn1 = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
+        conn1.setServerGroupName("ha_config1_group");
 
-        rs = conn.createStatement().executeQuery(query);
+        rs = conn1.createStatement().executeQuery(query);
         rs.next();
         String newMaster = rs.getString(1);
         System.err.println("New master: " + newMaster);
         assertFalse(startingMaster.equals(newMaster));
-        conn.close();
+        conn1.close();
     }
 
     /**
@@ -168,10 +169,10 @@ public class TestHABasics extends BaseFabricTestCase {
      * connections by being a part of the replication connection group.
      */
     public void manualTestFailedOldMasterDoesntBlockNewConnections() throws Exception {
-        FabricMySQLConnection conn = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
-        conn.setServerGroupName("ha_config1_group");
+        FabricMySQLConnection conn1 = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
+        conn1.setServerGroupName("ha_config1_group");
 
-        Statement s = conn.createStatement();
+        Statement s = conn1.createStatement();
 
         // run a query until a failure happens. this will cause the master connection in the replication connection to be closed
         try {
@@ -186,7 +187,7 @@ public class TestHABasics extends BaseFabricTestCase {
             System.err.println("Failure encountered: " + ex.getMessage());
             System.err.println("Waiting 10 seconds before trying a new connection");
             try {
-                Thread.sleep(10*1000);
+                Thread.sleep(10 * 1000);
             } catch (Exception ex2) {
             }
         }
@@ -195,25 +196,25 @@ public class TestHABasics extends BaseFabricTestCase {
         // removeMasterHost() call failed
 
         // make sure a new connection is successful
-        conn = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
-        conn.setServerGroupName("ha_config1_group");
+        conn1 = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
+        conn1.setServerGroupName("ha_config1_group");
 
-        ResultSet rs = conn.createStatement().executeQuery("SELECT CONCAT(@@hostname, ':', @@port) AS 'Value'");
+        ResultSet rs = conn1.createStatement().executeQuery("SELECT CONCAT(@@hostname, ':', @@port) AS 'Value'");
         rs.next();
         System.err.println("New master: " + rs.getString(1));
         rs.close();
-        conn.close();
+        conn1.close();
     }
 
     /**
      * Same as test `manualTestFailedOldMasterDoesntBlockNewConnections' for slaves. There must be only one slave in the HA group for this test.
      */
     public void manualTestFailedSingleSlaveDoesntBlockNewConnections() throws Exception {
-        FabricMySQLConnection conn = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
-        conn.setServerGroupName("ha_config1_group");
-        conn.setReadOnly(true);
+        FabricMySQLConnection conn1 = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
+        conn1.setServerGroupName("ha_config1_group");
+        conn1.setReadOnly(true);
 
-        Statement s = conn.createStatement();
+        Statement s = conn1.createStatement();
 
         // run a query until a failure happens. this will cause the slaves connection in the replication connection to be closed
         try {
@@ -229,7 +230,7 @@ public class TestHABasics extends BaseFabricTestCase {
             System.err.println("Failure encountered: " + ex.getMessage());
             System.err.println("Waiting 10 seconds before trying a new connection");
             try {
-                Thread.sleep(10*1000);
+                Thread.sleep(10 * 1000);
             } catch (Exception ex2) {
             }
         }
@@ -238,14 +239,14 @@ public class TestHABasics extends BaseFabricTestCase {
         // removeSlaveHost() call failed
 
         // make sure a new connection is successful
-        conn = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
-        conn.setServerGroupName("ha_config1_group");
-        conn.setReadOnly(true);
+        conn1 = (FabricMySQLConnection) this.ds.getConnection(this.username, this.password);
+        conn1.setServerGroupName("ha_config1_group");
+        conn1.setReadOnly(true);
 
-        ResultSet rs = conn.createStatement().executeQuery("SELECT CONCAT(@@hostname, ':', @@port) AS 'Value'");
+        ResultSet rs = conn1.createStatement().executeQuery("SELECT CONCAT(@@hostname, ':', @@port) AS 'Value'");
         rs.next();
         System.err.println("New slave: " + rs.getString(1));
         rs.close();
-        conn.close();
+        conn1.close();
     }
 }
