@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2002, 2016, Oracle and/or its affiliates. All rights reserved.
+  Copyright (c) 2002, 2017, Oracle and/or its affiliates. All rights reserved.
 
   The MySQL Connector/J is licensed under the terms of the GPLv2
   <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most MySQL Connectors.
@@ -30,12 +30,14 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.sql.CallableStatement;
 import java.sql.Connection;
+import java.sql.ParameterMetaData;
 import java.sql.PreparedStatement;
 import java.sql.ResultSetMetaData;
 import java.sql.SQLException;
 import java.sql.Statement;
 import java.sql.Types;
 import java.util.Properties;
+import java.util.concurrent.Callable;
 
 import com.mysql.jdbc.NonRegisteringDriver;
 import com.mysql.jdbc.SQLError;
@@ -1032,7 +1034,7 @@ public class CallableStatementRegressionTest extends BaseTestCase {
 
         createTable("testBug28689", "(" +
 
-        "`id` int(11) NOT NULL auto_increment,`usuario` varchar(255) default NULL,PRIMARY KEY  (`id`))");
+                "`id` int(11) NOT NULL auto_increment,`usuario` varchar(255) default NULL,PRIMARY KEY  (`id`))");
 
         this.stmt.executeUpdate("INSERT INTO testBug28689 (usuario) VALUES ('AAAAAA')");
 
@@ -1590,7 +1592,142 @@ public class CallableStatementRegressionTest extends BaseTestCase {
         call.registerOutParameter(1, Types.INTEGER);
         call.execute();
         assertEquals(10, call.getInt(1));
-
     }
 
+    /**
+     * Tests fix for Bug#79561 - NullPointerException when calling a fully qualified stored procedure
+     */
+    public void testBug79561() throws Exception {
+        createProcedure("testBug79561", "(OUT o VARCHAR(100)) BEGIN SELECT 'testBug79561 data' INTO o; END");
+
+        String dbName = this.conn.getCatalog();
+        String[] sql = new String[] { String.format("{CALL %s.testBug79561(?)}", dbName), String.format("{CALL `%s`.testBug79561(?)}", dbName),
+                String.format("{CALL %s.`testBug79561`(?)}", dbName), String.format("{CALL `%s`.`testBug79561`(?)}", dbName) };
+
+        for (int i = 0; i < sql.length; i++) {
+            for (int m = 0; m < 4; m++) { // Method call type: 0) by index; 1) by name; 2) by invalid index; 3) by invalid name;
+                final String testCase = String.format("Case: [sql: %d, method: %d ]", i, m);
+                final CallableStatement cstmt = this.conn.prepareCall(sql[i]);
+                boolean dataExpected = true;
+
+                // Register the output parameter using one of the different methods.
+                if (m == 0) {
+                    cstmt.registerOutParameter(1, Types.VARCHAR);
+                } else if (m == 1) {
+                    cstmt.registerOutParameter("o", Types.VARCHAR);
+                } else if (m == 2) {
+                    assertThrows(testCase, SQLException.class, "Parameter index of 2 is out of range \\(1, 1\\)", new Callable<Void>() {
+                        public Void call() throws Exception {
+                            cstmt.registerOutParameter(2, Types.VARCHAR);
+                            return null;
+                        }
+                    });
+                    dataExpected = false;
+                } else {
+                    assertThrows(testCase, SQLException.class, "No parameter named 'oparam'", new Callable<Void>() {
+                        public Void call() throws Exception {
+                            cstmt.registerOutParameter("oparam", Types.VARCHAR);
+                            return null;
+                        }
+                    });
+                    dataExpected = false;
+                }
+
+                // Check the returned data, if any expected, using different methods.
+                if (dataExpected) {
+                    cstmt.execute();
+                    assertEquals(testCase, "testBug79561 data", cstmt.getString(1));
+                    assertEquals(testCase, "testBug79561 data", cstmt.getString("o"));
+                    assertThrows(testCase, SQLException.class, "Parameter index of 2 is out of range \\(1, 1\\)", new Callable<Void>() {
+                        public Void call() throws Exception {
+                            cstmt.getString(2);
+                            return null;
+                        }
+                    });
+                    assertThrows(testCase, SQLException.class, "Column '@com_mysql_jdbc_outparam_oparam' not found\\.", new Callable<Void>() {
+                        public Void call() throws Exception {
+                            cstmt.getString("oparam");
+                            return null;
+                        }
+                    });
+                }
+
+                cstmt.close();
+            }
+        }
+    }
+
+    /**
+     * Tests fix for Bug#84324 - CallableStatement.extractProcedureName() not work when catalog name with dash.
+     */
+    public void testBug84324() throws Exception {
+        createDatabase("`testBug84324-db`");
+
+        /*
+         * Test procedure.
+         */
+        createProcedure("`testBug84324-db`.`testBug84324-proc`", "(IN a INT, INOUT b VARCHAR(100)) BEGIN SELECT a, b; END");
+
+        final CallableStatement cstmtP = this.conn.prepareCall("CALL testBug84324-db.testBug84324-proc(?, ?)");
+        ParameterMetaData pmd = cstmtP.getParameterMetaData();
+
+        assertEquals(2, pmd.getParameterCount());
+        // 1st parameter
+        assertEquals("INT", pmd.getParameterTypeName(1));
+        assertEquals(Types.INTEGER, pmd.getParameterType(1));
+        assertEquals(Integer.class.getName(), pmd.getParameterClassName(1));
+        assertEquals(ParameterMetaData.parameterModeIn, pmd.getParameterMode(1));
+        // 2nd parameter
+        assertEquals("VARCHAR", pmd.getParameterTypeName(2));
+        assertEquals(Types.VARCHAR, pmd.getParameterType(2));
+        assertEquals(String.class.getName(), pmd.getParameterClassName(2));
+        assertEquals(ParameterMetaData.parameterModeInOut, pmd.getParameterMode(2));
+
+        cstmtP.setInt(1, 1);
+        cstmtP.setString(2, "foo");
+        assertThrows(SQLException.class, new Callable<Void>() {
+            public Void call() throws Exception {
+                cstmtP.execute();
+                return null;
+            }
+        }); // Although the procedure metadata could be obtained, the end query actually fails due to syntax errors.
+        cstmtP.close();
+
+        /*
+         * Test function.
+         */
+        createFunction("`testBug84324-db`.`testBug84324-func`", "(a INT, b VARCHAR(123)) RETURNS INT BEGIN RETURN a + LENGTH(b); END");
+
+        final CallableStatement cstmtF = this.conn.prepareCall("{? = CALL testBug84324-db.testBug84324-func(?, ?)}");
+        pmd = cstmtF.getParameterMetaData();
+
+        assertEquals(3, pmd.getParameterCount());
+        // 1st parameter
+        assertEquals("INT", pmd.getParameterTypeName(1));
+        assertEquals(Types.INTEGER, pmd.getParameterType(1));
+        assertEquals(Integer.class.getName(), pmd.getParameterClassName(1));
+        assertEquals(ParameterMetaData.parameterModeOut, pmd.getParameterMode(1));
+        // 2nd parameter
+        assertEquals("INT", pmd.getParameterTypeName(2));
+        assertEquals(Types.INTEGER, pmd.getParameterType(2));
+        assertEquals(Integer.class.getName(), pmd.getParameterClassName(2));
+        assertEquals(ParameterMetaData.parameterModeIn, pmd.getParameterMode(2));
+        // 3rd parameter
+        assertEquals("VARCHAR", pmd.getParameterTypeName(3));
+        assertEquals(Types.VARCHAR, pmd.getParameterType(3));
+        assertEquals(String.class.getName(), pmd.getParameterClassName(3));
+        assertEquals(ParameterMetaData.parameterModeIn, pmd.getParameterMode(3));
+
+        cstmtF.registerOutParameter(1, Types.INTEGER);
+        cstmtF.setInt(2, 1);
+        cstmtF.setString(3, "foo");
+        assertThrows(SQLException.class, new Callable<Void>() {
+            public Void call() throws Exception {
+                cstmtF.execute();
+                return null;
+            }
+        }); // Although the function metadata could be obtained, the end query actually fails due to syntax errors.
+        cstmtP.close();
+        cstmtF.close();
+    }
 }
\ No newline at end of file
